<?php

namespace Drupal\Tests\media_remote_audio\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\media_remote_audio\SoundCloudAwareResourceFetcher;
use GuzzleHttp\Client;
use GuzzleHttp\Handler\MockHandler;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Psr7\Response;

/**
 * Tests that XML resources with dashed properties are handled properly.
 *
 * @group media_remote_audio
 */
class DashedPropertiesXmlResourceTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'media',
    'media_remote_audio',
  ];

  /**
   * Tests that dashed properties in XML resources are correctly interpreted.
   */
  public function testXmlResourceWithDashedProperties() {
    $response_xml = <<<END
<?xml version="1.0" encoding="UTF-8"?>
<oembed>
  <version type="float">1.0</version>
  <type>rich</type>
  <provider-name>SoundCloud</provider-name>
  <provider-url>https://soundcloud.com</provider-url>
  <height type="integer">400</height>
  <width>100%</width>
  <title>LTJ Bukem &amp; MC Conrad - Progression Sessions 01 (1998) 70m Studio mix by DJ Jo Public (Two-Step2)</title>
  <description>Soulful deep intelligent dnb at its finest. It doesn't get any better than this. Technically perfect mixing from Bukem with sublime track selection and outstanding lyrics from the one and only MC Conrad. A moment in time that should never be forgotten. Simply perfection, step by step, the deeper we go the higher we climb...
01.Cedar - Equinox
02.Intense - Eastern Promise
03.KMC - System
04.Motiv One - Cosmik
05.PHD &amp; Conrad - Presence
06.Big Bud - Emotionography
07.Seba - Planetary Funk Alert
08.Bio-Wire - Karizma
09.Artemis - Inner Worlds
10.Seba - Camouflage
11.LTJ Bukem - Orchestral Jam

I don't mean to infringe any copyrights, simply trying to spread good music. I highly suggest you go buy a copy of this to get it in full HD quality.</description>
  <thumbnail-url>https://i1.sndcdn.com/artworks-000638646496-2gbaar-t500x500.jpg</thumbnail-url>
  <html>&lt;iframe width="100%" height="400" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?visual=true&amp;url=https%3A%2F%2Fapi.soundcloud.com%2Ftracks%2F229974966&amp;show_artwork=true"&gt;&lt;/iframe&gt;</html>
  <author-name>DJ Jo Public (Two-Step2)</author-name>
  <author-url>https://soundcloud.com/dj-jo-public</author-url>
</oembed>
END;
    $headers = [
      'Content-Type' => ['application/xml'],
    ];
    $response = new Response(200, $headers, $response_xml);
    $mock = new MockHandler([$response]);
    $client = new Client([
      'handler' => HandlerStack::create($mock),
    ]);

    $fetcher = new SoundCloudAwareResourceFetcher(
      $client,
      $this->createMock('\Drupal\media\OEmbed\ProviderRepositoryInterface')
    );

    $resource = $fetcher->fetchResource('https://example.com/resource.xml');
    $this->assertInstanceOf('\Drupal\Core\Url', $resource->getThumbnailUrl());
    $this->assertSame(500, $resource->getThumbnailWidth());
    $this->assertSame(500, $resource->getThumbnailHeight());
  }

}
